GlobalExecutor

Struct GlobalExecutor 

pub struct GlobalExecutor;
Global async executor abstraction for spawning tasks.

This abstraction allows swapping the underlying executor for deterministic simulation testing. In production, it delegates to tokio. For deterministic simulation, use Turmoil which provides deterministic task scheduling.

Usage

use freenet::config::GlobalExecutor;
GlobalExecutor::spawn(async { /* task */ });

Implementations

Source

impl GlobalExecutor

pub fn spawn<R: Send + 'static>( f: impl Future<Output = R> + Send + 'static, ) -> JoinHandle<R>