enable_fast_crash_exit_code

Function enable_fast_crash_exit_code 

pub fn enable_fast_crash_exit_code()
Opt in to the distinct [FAST_CRASH_EXIT_CODE] for fast boot-crashes (#4551). Call ONLY from the production node entry point, and ONLY after confirming the supervising systemd unit advertises support for exit 45 (see the entry point’s marker check). See [EMIT_FAST_CRASH_EXIT_CODE].