pub fn reset_global_node_index()Expand description
Reset the global node index counter to initial state for this thread. Thread-local, so safe for parallel test execution.
pub fn reset_global_node_index()Reset the global node index counter to initial state for this thread. Thread-local, so safe for parallel test execution.