pub struct TelemetryReporter { /* private fields */ }Expand description
Telemetry reporter that sends events to a central OTLP collector.
Implementations
Sourceimpl TelemetryReporter
impl TelemetryReporter
Sourcepub fn new(config: &TelemetryConfig) -> Option<Self>
pub fn new(config: &TelemetryConfig) -> Option<Self>
Create a new telemetry reporter.
Returns None if telemetry is disabled or in a test environment.