StateStore

Struct StateStore 

pub struct StateStore<S: StateStorage> { /* private fields */ }
StateStore wraps a persistent storage backend with an optional in-memory cache. It is Clone when the underlying storage S is Clone (e.g., ReDb with Arc).

For deterministic simulation testing, use new_uncached() to bypass the stretto cache which has non-deterministic TinyLFU admission policy and background workers.

Implementations

Source

impl<S> StateStore<S>
where S: StateStorage + Send + 'static, <S as StateStorage>::Error: Into<Error>,

pub fn new(store: S, max_size: u32) -> Result<Self, StateStoreError>

Create a StateStore with stretto caching enabled.

Arguments
  • max_size: max number of bytes for the mem cache
pub fn new_uncached(store: S) -> Self

Create a StateStore without caching for deterministic simulation.

This bypasses the stretto AsyncCache which has non-deterministic behavior:

  • TinyLFU admission policy can reject inserts non-deterministically
  • Background workers for cache eviction and write batching

Use this constructor for deterministic simulation testing under turmoil.

pub async fn update( &mut self, key: &ContractKey, state: WrappedState, ) -> Result<(), StateStoreError>

pub async fn store( &mut self, key: ContractKey, state: WrappedState, params: Parameters<'static>, ) -> Result<(), StateStoreError>

pub async fn get( &self, key: &ContractKey, ) -> Result<WrappedState, StateStoreError>

pub async fn get_params<'a>( &'a self, key: &'a ContractKey, ) -> Result<Option<Parameters<'static>>, StateStoreError>

pub fn inner(&self) -> &S

Get a reference to the underlying storage backend. Used for hosting metadata persistence operations.

pub fn storage(&self) -> S
where S: Clone,

Get a clone of the underlying storage backend. Used when the storage needs to be shared with other components (e.g., ContractStore, DelegateStore, SecretsStore).