pub struct StateStore<S: StateStorage> { /* private fields */ }Expand description
StateStore wraps a persistent storage backend with an optional in-memory cache.
It is Clone when the underlying storage S is Clone (e.g., ReDb with Arc
For deterministic simulation testing, use new_uncached() to bypass the stretto
cache which has non-deterministic TinyLFU admission policy and background workers.
Implementations
Sourceimpl<S> StateStore<S>
impl<S> StateStore<S>
Sourcepub fn new(store: S, max_size: u32) -> Result<Self, StateStoreError>
pub fn new(store: S, max_size: u32) -> Result<Self, StateStoreError>
Create a StateStore with stretto caching enabled.
Arguments
- max_size: max number of bytes for the mem cache
Sourcepub fn new_uncached(store: S) -> Self
pub fn new_uncached(store: S) -> Self
Create a StateStore without caching for deterministic simulation.
This bypasses the stretto AsyncCache which has non-deterministic behavior:
- TinyLFU admission policy can reject inserts non-deterministically
- Background workers for cache eviction and write batching
Use this constructor for deterministic simulation testing under turmoil.
pub async fn update( &mut self, key: &ContractKey, state: WrappedState, ) -> Result<(), StateStoreError>
pub async fn store( &mut self, key: ContractKey, state: WrappedState, params: Parameters<'static>, ) -> Result<(), StateStoreError>
pub async fn get( &self, key: &ContractKey, ) -> Result<WrappedState, StateStoreError>
pub async fn get_params<'a>( &'a self, key: &'a ContractKey, ) -> Result<Option<Parameters<'static>>, StateStoreError>