pub struct SimulationRng { /* private fields */ }Expand description
A thread-safe, seeded random number generator for simulation.
All random decisions during simulation should go through this RNG to ensure deterministic replay when using the same seed.
Determinism
For deterministic replay:
- All random decisions must use this RNG
- Random calls must happen in the same order each run
- Parallel access must be serialized (handled internally by Mutex)
Implementations
Sourceimpl SimulationRng
impl SimulationRng
Sourcepub fn gen_bool(&self, probability: f64) -> bool
pub fn gen_bool(&self, probability: f64) -> bool
Generates a random boolean with the given probability of being true.
Sourcepub fn gen_range(&self, range: Range<usize>) -> usize
pub fn gen_range(&self, range: Range<usize>) -> usize
Generates a random usize in the given range.
Sourcepub fn gen_range_u64(&self, range: Range<u64>) -> u64
pub fn gen_range_u64(&self, range: Range<u64>) -> u64
Generates a random u64 in the given range.
Sourcepub fn gen_duration(&self, range: Range<Duration>) -> Duration
pub fn gen_duration(&self, range: Range<Duration>) -> Duration
Generates a random Duration within the given range.
Sourcepub fn choose<'a, T>(&self, slice: &'a [T]) -> Option<&'a T>
pub fn choose<'a, T>(&self, slice: &'a [T]) -> Option<&'a T>
Chooses a random element from a slice, returning None if empty.
Sourcepub fn shuffle<T>(&self, slice: &mut [T])
pub fn shuffle<T>(&self, slice: &mut [T])
Shuffles a slice in-place using Fisher-Yates algorithm.
Sourcepub fn child(&self) -> Self
pub fn child(&self) -> Self
Creates a child RNG with a derived seed.
This is useful for giving each peer its own RNG while maintaining overall determinism - the child’s seed is derived from the parent’s current state.
Sourcepub fn child_with_index(&self, index: u64) -> Self
pub fn child_with_index(&self, index: u64) -> Self
Creates a child RNG with a specific derived seed based on an index.
This ensures that child RNGs are created deterministically regardless of the order in which they’re requested, as long as the indices are consistent.
Sourcepub fn lock(&self) -> MutexGuard<'_, SmallRng>
pub fn lock(&self) -> MutexGuard<'_, SmallRng>
Access the inner RNG for operations that need direct Rng trait access.
Warning
The returned guard holds the lock. Be careful not to hold it across await points or other blocking operations.